@@ -1,4 +1,4 @@
-setMethodS3("allocateFromCdf", "AromaCellMatchScoreFile", function(static, cdf, path=getPath(cdf), tags="*", ...) {
+setMethodS3("allocateFromCdf", "AromaCellMatchScoreFile", function(static, cdf, path=NULL, tags="*", ...) {
   # Argument 'cdf':
   cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
 
@@ -12,6 +12,13 @@ setMethodS3("allocateFromCdf", "AromaCellMatchScoreFile", function(static, cdf,
   tags[tags == "*"] <- paste(parts[-1], collapse=",");
   chipType <- parts[1];
   chipType <- gsub(",monocell", "", chipType);
+
+  # Output path
+  if (is.null(path)) {
+    path <- file.path("annotationData", "chipTypes", chipType);
+  }
+  path <- Arguments$getWritablePath(path);
+
   platform <- getPlatform(cdf);
   nbrOfCells <- nbrOfCells(cdf);
   fullname <- paste(c(chipType, tags), collapse=",");
@@ -24,6 +31,11 @@ setMethodS3("allocateFromCdf", "AromaCellMatchScoreFile", function(static, cdf,
 
 ############################################################################
 # HISTORY:
+# 2011-02-28
+# o STANDARDIZATION: Now the default output path for all allocateFromCdf()
+#   is annotationData/chipTypes/<chipType>/.  Before it was the same
+#   directory as the CDF, which may for instance have been in a deeper
+#   subdirectory, or recently also in a sibling root path.
 # 2010-03-14 [HB]
 # o BUG FIX: allocateFromCdf() of AromaCellMatchScoreFile would drop all
 #   but the first tag.
