@@ -61,12 +61,13 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
   verbose && enter(verbose, "Extracting unit data");
   count <- 1;
   while (length(unitsToDo) > 0) {
+    verbose && enter(verbose, sprintf("Chunk #%d of %d", count, nbrOfChunks));
+
     if (length(unitsToDo) < unitsPerChunk) {
       head <- 1:length(unitsToDo);
     }
     units <- unitsToDo[head];
-    verbose && printf(verbose, "Chunk #%d of %d (%d units)\n",
-                                        count, nbrOfChunks, length(units));
+    verbose && cat(verbose, "Number of units: ", length(units));
 
     residualsList <- readUnits(rs, units=units, verbose=less(verbose), stratifyBy="pm");
 
@@ -74,38 +75,38 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
     weightsList <- base::lapply(residualsList, FUN=resFcn);
     verbose && exit(verbose);
     
-# update output files
-    
     verbose && enter(verbose, "Storing weights");
 
     cdf <- getCellIndices(getCdf(ds), units=units, stratifyBy="pm", ...);
     
-    for (kk in seq(ds)) {
-      wf <- getFile(ws, kk);
+    for (ii in seq(ds)) {
+      wf <- getFile(ws, ii);
 
-      verbose && enter(verbose, sprintf("Array #%d ('%s')", kk, getName(wf)));
+      verbose && enter(verbose, sprintf("Array #%d ('%s') of %d", ii, getName(wf), length(ds)));
 
-      data <- base::lapply(weightsList, function(unit){
+      data <- base::lapply(weightsList, function(unit) {
         base::lapply(unit, function(group) {
           nrow <- nrow(group); 
           list(
-               intensities=2^group[,kk], 
-               stdvs=rep(1, nrow), 
-               pixels=rep(1, nrow)
-               );
-        })
+            intensities=2^group[,ii], 
+            stdvs=rep(1, times=nrow), 
+            pixels=rep(1, times=nrow)
+          );
+        });
       });
       
       updateCelUnits(getPathname(wf), cdf=cdf, data=data);
 
       verbose && exit(verbose);
-    }
+    } # for (ii ...)
     
     verbose && exit(verbose);
 
     unitsToDo <- unitsToDo[-head];
     count <- count + 1;
-  }
+
+    verbose && exit(verbose);
+  } # while (...)
 
   if (exists("residualsList")) {
     rm(residualsList);
@@ -126,6 +127,8 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
 
 ##########################################################################
 # HISTORY:
+# 2011-03-01 [HB]
+# o Harmonized the verbose output.
 # 2007-02-15 
 # o Based on ProbeLevelModel.calculateResiduals
 #   and QualityAssessmentModel.getWeights
